==> dde-shell_2.0.15.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN hapur</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN mbyllur</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Shkronja të Mëdha aktive</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Shkronja të Mëdha joaktive</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Pjesa numerike aktive</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Pjesa numerike joaktive</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad-i aktiv</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad-i joaktiv</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Aktivizim/çaktivizim Touchpad-i</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Këmbim Fn-je</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mënyra aeroplan aktive</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mënyra aeroplan joaktive</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Balancim energjie</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Kursyes energjie</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>U aktivizuan efekte dritaresh</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>U çaktivizuan efekte dritaresh</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>S’u arrit të aktivizohen efekte dritaresh</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Mikrofoni fikur</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Mikrofoni hapur</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.19.tar.xz: BUILD/panels/notification/osd/default/translations/org.deepin.ds.osd.default_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN hapur</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN mbyllur</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Shkronja të Mëdha aktive</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Shkronja të Mëdha joaktive</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Pjesa numerike aktive</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Pjesa numerike joaktive</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Touchpad-i aktiv</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Touchpad-i joaktiv</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Aktivizim/çaktivizim Touchpad-i</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Këmbim Fn-je</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Mënyra aeroplan aktive</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Mënyra aeroplan joaktive</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Balancim energjie</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Kursyes energjie</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>U aktivizuan efekte dritaresh</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>U çaktivizuan efekte dritaresh</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>S’u arrit të aktivizohen efekte dritaresh</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation>Mikrofoni fikur</translation>
    </message>
    <message>
        <source>Microphone on</source>
        <translation>Mikrofoni hapur</translation>
    </message>
    <message>
        <source>Camera on</source>
        <translation>Kamera hapur</translation>
    </message>
    <message>
        <source>Camera off</source>
        <translation>Kamera mbyllur</translation>
    </message>
</context>
</TS>
